@@ -445,6 +445,7 @@
   (setf (get c 'defh) nil))
 
 (defun declare-basetype (a)
+  (when (or (get a 'basetp) (get a 'const) (get a 'def)) (thf-fail "Redeclaration of base type" a))
   (setf (get a 'basetp) t)
   (when *choice-as-default* (set-default-elt (ap (lepsilon a) (lam a *FALSE*)))) ; Use choose x . \bot as default elt
   (push a *sorts*)
@@ -452,6 +453,7 @@
   nil)
 
 (defun declare-const (c a)
+  (when (or (get c 'basetp) (get c 'const) (get c 'def)) (thf-fail "Redeclaration of constant" (list c a)))
   (setf (get c 'const) a)
   (setf (get c 'consth) (cons c a))
   (setf (get c 'rtp) (rtp a))
@@ -464,6 +466,7 @@
   nil)
 
 (defun declare-def (c m)
+  (when (or (get c 'basetp) (get c 'def)) (thf-fail "Redeclaration of constant" (list c a)))
   (let ((a (cdr m)))
     (when (get c 'const)
       (if (eq a (get c 'const))
@@ -1906,13 +1909,9 @@
 	      )
 	  (if (eq foo 'thf-fail)
 	      (progn
-		(unless *slave*
-		  (format t "% SZS status Error : (THF Error)~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
-		  )
+		(format t "% SZS status Error : (THF Error)~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
 		2)
 	    (progn
-	      (unless *slave*
-		(format t "% SZS status Error~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
-		)
+	      (format t "% SZS status Error~%") ; Geoff Sutcliffe, Jan 2010 - SZS standard output
 	      3)))))))
 
