@@ -71,6 +71,7 @@
 		      (dotimes (i (length op))
 			(when (> i 0)
 			  (case (aref op i)
+				(#\V (satallax-version) (sb-ext:quit :unix-status 0))
 				(#\p (setq *print-final-proof-info* t))
 				(#\v (setq *verbose* t))
 				(#\S (setq *fresh-images* nil))
@@ -147,7 +148,7 @@
 					       (sb-ext:process-kill p 9)
 					       (when *verbose* (format t "** Killed mode ~d for ~d seconds~%" (caar *strategy*) ltimeout))
 					       (setq timeout (- timeout 2))))
-				     (when (member e '(10 15 20 25) :test #'equal)
+				     (when (member e '(0 1 2 3 10 15 20 25) :test #'equal)
 				       (setq succ e))
 				     (pop *strategy*)))
 			       (progn
@@ -165,7 +166,7 @@
 					(format t "*** Did not find mode file: ~d~%ABORT~%" modefile)
 					(throw 'failure 1)))
 				    (let ((e (hol2sat-file problemfile)))
-				     (when (member e '(10 15 20 25) :test #'equal)
+				     (when (member e '(0 1 2 3 10 15 20 25) :test #'equal)
 				       (setq succ e))))
 				  (timeout ()
 					   (when *verbose* (format t "~d timed out.~%" (caar *strategy*)))
@@ -179,9 +180,10 @@
 		   (hol2sat-file problemfile)
 		   ))))
 	 (progn
-	   (format t "No file given.~%Usage: satallax [-[vp]] [-M <MiniSat>] [-m <modefile>] [-t <timeout in seconds>] <problemfile>~%")
+	   (format t "No file given.~%Usage: satallax [-[Vvp]] [-M <MiniSat>] [-m <modefile>] [-t <timeout in seconds>] <problemfile>~%")
 	   (format t "-m : Mode~%")
 	   (format t "-M : MiniSat binary file~%")
+	   (format t "-V : Print version number and quit~%")	   
 	   (format t "-v : Verbose~%")
 	   (format t "-p : Print information about the final proof (clauses and atlas of atoms).~%")
 ;	   (format t "-S : Run modes sequentially without starting new lisp images.~%")
